"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useContextAxiosClient = exports.AxiosClientsManager = exports.AxiosClientsContext = void 0;
var react_1 = require("react");
/**
 * React context to hold AxiosClientManager instance
 */
exports.AxiosClientsContext = react_1.createContext(null);
/**
 * Used as the IoC container to inject axios client instances into components
 * based on their names
 */
var AxiosClientsManager = /** @class */ (function () {
    function AxiosClientsManager(clients) {
        this.clients = clients;
    }
    AxiosClientsManager.prototype.getClient = function (key) {
        if (key === void 0) { key = 'default'; }
        return this.clients[key];
    };
    return AxiosClientsManager;
}());
exports.AxiosClientsManager = AxiosClientsManager;
/**
 * Injects axios client from the context based on the provided name or
 * uses the provided instance. If called without arguments, uses the default
 * instance
 *
 * @param clientOrName - name of the axios client to be injected, or instance to be used
 */
function useContextAxiosClient(clientOrName) {
    var clientsContext = react_1.useContext(exports.AxiosClientsContext);
    if (!clientOrName || typeof clientOrName === 'string') {
        if (!clientsContext) {
            throw new Error("AxiosClientsContext is not provided");
        }
        var client = !clientOrName ? clientsContext.getClient() : clientsContext.getClient(clientOrName);
        if (!client) {
            throw new Error("Client '" + clientOrName + "' is not found in the AxiosClientsContext store");
        }
        return client;
    }
    return clientOrName;
}
exports.useContextAxiosClient = useContextAxiosClient;
//# sourceMappingURL=AxiosClientsContext.js.map