import { __assign, __rest } from "tslib";
import { useContext, useMemo } from 'react';
import { AxiosQueryStore } from '@proscom/prostore-axios';
import { ProstoreSsrContext, useRequestStore } from '@proscom/prostore-react';
import { useContextAxiosClient } from './AxiosClientsContext';
/**
 * Creates AxiosQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the axios based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
export function useAxiosQuery(_a) {
    var client = _a.client, queryOptions = _a.queryOptions, variables = _a.variables, options = _a.options, hookOptions = _a.hookOptions;
    var actualClient = useContextAxiosClient(client);
    var ssrContext = useContext(ProstoreSsrContext);
    var store = useMemo(function () {
        return new AxiosQueryStore(__assign({ ssrContext: ssrContext, client: actualClient }, queryOptions));
    }, [ssrContext, actualClient, queryOptions]);
    return useRequestStore(store, variables, options, hookOptions);
}
/**
 * The same as useAxiosQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 * @deprecated This function is not needed since useAxiosQuery performs deep equality check
 * on variables
 */
export function useAxiosQueryVars(_a) {
    var variableCreator = _a.variableCreator, queryProps = __rest(_a, ["variableCreator"]);
    var variables = useMemo.apply(void 0, variableCreator);
    return useAxiosQuery(__assign(__assign({}, queryProps), { variables: variables }));
}
//# sourceMappingURL=useAxiosQuery.js.map