"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAxiosQueryVars = exports.useAxiosQuery = void 0;
var tslib_1 = require("tslib");
var react_1 = require("react");
var prostore_axios_1 = require("@proscom/prostore-axios");
var prostore_react_1 = require("@proscom/prostore-react");
var AxiosClientsContext_1 = require("./AxiosClientsContext");
/**
 * Creates AxiosQueryStore and subscribes to it using useRequestStore.
 * Effectively this requests data from the axios based on the provided variables and queryOptions
 *
 * @returns {{load, check, state}} - Current request state
 */
function useAxiosQuery(_a) {
    var client = _a.client, queryOptions = _a.queryOptions, variables = _a.variables, options = _a.options, hookOptions = _a.hookOptions;
    var actualClient = AxiosClientsContext_1.useContextAxiosClient(client);
    var ssrContext = react_1.useContext(prostore_react_1.ProstoreSsrContext);
    var store = react_1.useMemo(function () {
        return new prostore_axios_1.AxiosQueryStore(tslib_1.__assign({ ssrContext: ssrContext, client: actualClient }, queryOptions));
    }, [ssrContext, actualClient, queryOptions]);
    return prostore_react_1.useRequestStore(store, variables, options, hookOptions);
}
exports.useAxiosQuery = useAxiosQuery;
/**
 * The same as useAxiosQuery, but it uses variableCreator which is supplied to useMemo and
 * can be used to memoize query variables. This may be used when the default behavior of deeply
 * comparing variables is not preferable (i.e., it is not fast enough, or variables are not simple objects)
 *
 * @returns {{load, check, state}} - Current request state
 * @deprecated This function is not needed since useAxiosQuery performs deep equality check
 * on variables
 */
function useAxiosQueryVars(_a) {
    var variableCreator = _a.variableCreator, queryProps = tslib_1.__rest(_a, ["variableCreator"]);
    var variables = react_1.useMemo.apply(void 0, variableCreator);
    return useAxiosQuery(tslib_1.__assign(tslib_1.__assign({}, queryProps), { variables: variables }));
}
exports.useAxiosQueryVars = useAxiosQueryVars;
//# sourceMappingURL=useAxiosQuery.js.map